@@ -31,5 +31,5 @@ datout = [{'file': fout, \
 # function definition:
 func = lambda U,V: np.array([np.mean(np.sqrt(U**2+V**2),axis=0 )])
 dnamsel = ['level',]
-pcd.pcd(func,dnamsel,datin,datout,appenddim=True)
+pcd.pcd(func,dnamsel,datin,datout,appenddim=True,order=('rlon','rlat'))
 print 'output data written to:',fnout
