@@ -18,9 +18,9 @@ datout = [{'file':fout,'varname':'T'},]
 # selection of function dimension input
 func = lambda x, y: (np.array([np.mean(x,axis=0)],dtype=np.float32) ,) # *(1.+np.zeros(x.shape))
 dnamsel = ['time',]
-pcd.pcd(func,dnamsel,datin,datout)
+pcd.pcd(func,dnamsel,datin,datout,appenddim=True)
 
-fout.close()
+fout.close();print('output file written to:',fout )
 
 
 # fig = pl.figure()
