@@ -312,7 +312,14 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
 
         vsdin[idatin]['itemsize'] = nctemp.variables[datin[idatin]['varname']].itemsize()
         vsdin[idatin]['dtype']  =   nctemp.variables[datin[idatin]['varname']]._dtype
+        # print(vsdin[idatin]['dtype'])
         vsdin[idatin]['voffset']  = nctemp.variables[datin[idatin]['varname']]._voffset
+        
+        # additional attributes of the netcdf files we want to add to the file description
+        props = ['add_offset','scale_factor']
+        for prop in props:
+            if prop in dir(nctemp.variables[datin[idatin]['varname']]):
+                vsdin[idatin][prop] = nctemp.variables[datin[idatin]['varname']].__getattribute__(prop)
 
         # dselmarker
         vsdin[idatin]['dsel'] = [range(e) for e in vsdin[idatin]['dims']]
@@ -352,6 +359,15 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
             vsdout[idatout]['itemsize'] = nctemp.variables[datout[idatout]['varname']].itemsize()
             vsdout[idatout]['dtype']=     nctemp.variables[datout[idatout]['varname']]._dtype
             vsdout[idatout]['voffset'] =  nctemp.variables[datout[idatout]['varname']]._voffset
+
+            # additional attributes of the netcdf files we want to add to the file description
+            props = ['add_offset','scale_factor']
+            for prop in props:
+                if prop in dir(nctemp.variables[datout[idatout]['varname']]):
+                    vsdout[idatout][prop] = nctemp.variables[datout[idatout]['varname']].__getattribute__(prop)
+
+
+
             nctemp.close()
             #datout[idatout]['file'] = NetCDF.NetCDFFile(ncfn,'a')
         else:
@@ -1049,6 +1065,10 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
                 vsdin[ivsdin]['voffset'],\
                 rwchunksizein[ivsdin],\
                 ), dtype=vsdin[ivsdin]['dtype']).ravel())
+            if 'scale_factor' in vsdin[ivsdin]:
+                dataicecubein[-1] =  dataicecubein[-1]*vsdin[ivsdin]['scale_factor']
+            if 'add_offset' in vsdin[ivsdin]:
+                dataicecubein[-1] =  dataicecubein[-1] + vsdin[ivsdin]['add_offset']
     
         dataicecubeout = []
         for ilendnoiterout,elendnoiterout in enumerate(alendnoiterout):
@@ -1134,6 +1154,12 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000,
             dataicecubeout[idimsout].shape = [len(e) for e in adimnoiterout[idimsout]]
     
         for ivsdout in range(len(vsdout)):
+            # before the write out, we convert the numbers according to the output offset and scalefactor
+            if 'add_offset' in vsdout[ivsdout]:
+                dataicecibeout[ivsdout] =  dataicecibeout[-1] - vsdout[ivsdout]['add_offset']
+            if 'scale_factor' in vsdout[ivsdout]:
+                dataicecibeout[ivsdout] =  dataicecibeout[-1]/vsdout[ivsdout]['scale_factor']
+            
             writeicecubeps(\
                 vsdout[ivsdout]['fp'],
                 vsdout[ivsdout]['dims'],\
